@@ -2,8 +2,8 @@ package HTML::StripScripts::Parser;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.02';
-# $Rev: 75 $
+$VERSION = '0.04';
+# $Rev: 97 $
 
 =head1 NAME
 
@@ -13,7 +13,11 @@ HTML::StripScripts::Parser - XSS filter using HTML::Parser
 
   use HTML::StripScripts::Parser;
 
-  my $hss = HTML::StripScripts::Parser->new({ Context => 'Document' });
+  my $hss = HTML::StripScripts::Parser->new(
+       { Context => 'Document' },
+       strict_comment => 1,
+       strict_names   => 1,
+  );
 
   $hss->parse_file("foo.html");
 
@@ -33,7 +37,7 @@ See L<HTML::StripScripts> and L<HTML::Parser>.
 
 =over
 
-=item new ( CONFIG )
+=item new ( CONFIG, [PARSER_OPTIONS]  )
 
 Creates a new C<HTML::StripScripts::Parser> object, and invokes the
 L<HTML::Parser> init() method so that tags are fed to the correct
@@ -42,6 +46,13 @@ L<HTML::StripScripts> methods.
 The CONFIG parameter has the same semantics as the CONFIG
 parameter to the L<HTML::StripScripts> constructor.
 
+Any PARSER_OPTIONS supplied will be passed on to the L<HTML::Parser>
+init method, allowing you to influence the way the input is parsed.
+
+You cannot use PARSER_OPTIONS to set L<HTML::Parser> event handlers,
+since C<HTML::StripScripts::Parser> uses all of the event hooks
+itself.
+
 =cut
 
 use HTML::StripScripts;
@@ -49,18 +60,27 @@ use HTML::Parser;
 use base qw(HTML::StripScripts HTML::Parser);
 
 sub hss_init {
-    my ($self, $cfg) = @_;
+    my ($self, $cfg, @parser_options) = @_;
 
     $self->init(
-       api_version => 3,
+       @parser_options,
+
+       api_version      => 3,
        start_document_h => ['input_start_document', 'self'],
        start_h          => ['input_start',          'self,text'],
        end_h            => ['input_end',            'self,text'],
        text_h           => ['input_text',           'self,text'],
+       default_h        => ['input_text',           'self,text'],
        declaration_h    => ['input_declaration',    'self,text'],
        comment_h        => ['input_comment',        'self,text'],
        process_h        => ['input_process',        'self,text'],
        end_document_h   => ['input_end_document',   'self'],
+
+       # workaround for http://rt.cpan.org/NoAuth/Bug.html?id=3954
+       ( $HTML::Parser::VERSION =~ /^3\.(29|30|31)$/
+           ?  ( strict_comment => 1 )
+           :  ()
+       ),
     );
 
     $self->SUPER::hss_init($cfg);
